/* \file threadedexecutor
 * \brief Runs commands in a new thread
 */

/*
  Originally written by Doug Lea and released into the public domain.
  This may be used for any purposes whatsoever without acknowledgment.
  Thanks for the assistance and support of Sun Microsystems Labs,
  and everyone contributing, testing, and using this code.

  History:
  Date       Who                What
	01May2004  Mike Swieton     Translated to D
  28aug1998  dl               refactored from Executor classes
*/

module concurrent.threadfactoryuser;

import concurrent.threadfactory;

/**
 * 
 * Base class for Executors and related classes that rely on thread factories.
 * Generally intended to be used as a mixin-style abstract class, but
 * can also be used stand-alone.
 **/

public class ThreadFactoryUser {

	protected:
		ThreadFactory threadFactory_;

		class DefaultThreadFactory : ThreadFactory {
			public Thread newThread(int delegate() command) {
				return new Thread(command);
			}
		}

	public:
		/**
		 * Create a new ThreadFactoryUser
		 **/
		this()
		{
			threadFactory_ = new DefaultThreadFactory();
		}

		/** 
		 * Set the factory for creating new threads.
		 * By default, new threads are created without any special priority,
		 * threadgroup, or status parameters.
		 * You can use a different factory
		 * to change the kind of Thread class used or its construction
		 * parameters.
		 * @param factory the factory to use
		 * @return the previous factory
		 **/
		synchronized ThreadFactory setThreadFactory(ThreadFactory factory) {
			ThreadFactory old = threadFactory_;
			threadFactory_ = factory;
			return old;
		}

		/** 
		 * Get the factory for creating new threads.
		 **/  
		synchronized ThreadFactory getThreadFactory() {
			return threadFactory_;
		}
}
